# hydrocomp: Package Python for hydrological data analysis

## What is it?

## Main Features

## Where to get it
The source code is currently hosted on GitHub at:
https://github.com/clebsonpy/HydroComp

Binary installers for the latest released version are available at the [Python
package index](https://pypi.org/project/hydrocomp/) and on conda.

```sh
pip install hydrocomp
```

## Dependencies
- [NumPy](https://www.numpy.org)
- [Pandas](https://pandas.pydata.org/)

See the [full installation instructions](https://pypi.org/project/hydrocomp/) for minimum supported versions of required, recommended and optional dependencies.

[MIT](LICENSE)

## Documentation
The official documentation is hosted on :
